﻿package {
	import flash.events.Event;
	import flash.display.MovieClip;
	import flash.display.Loader;
	import flash.media.Sound;
	import flash.net.URLRequest;
	import flash.events.TimerEvent;
	import flash.utils.Timer;
	import flash.external.ExternalInterface;

	public class FlagMovie extends MovieClip {
		
		// unique curlypage identifier
		private var cpid:uint;

		// in transition for peel add. Values: Blinds, Fade, Fly, Iris, Photo, Rotate, Squeeze, Wipe, PixelDissolve, Zoom.
		private var inTransition:String;
		// transition duration parameter
		private var transitionDuration:uint;
		
		// style of flag
		private var flagStyle:String;

		// size of design flag
		private const FLAGDESIGNSIZE:uint = 100;
		// flag width and height. Suggested values 10-200
		private var flagWidth:uint;
		private var flagHeight:uint;

		// peel position on page. Values: topleft || topright || bottomleft || bottomright
		private var peelPosition:String;

		// ad image on close peel
		private var smallURL:String;
		// mirror the image on peel. Values: true || false
		private var mirror:Boolean;

		// color of peel. Values: golden || silver || custom
		private var peelColor:String;
		// color of peel style. Value: flat || gradient
		private var peelColorStyle:String;
		// red value of custom color. Values 0-255
		private var redValue:uint;
		// green value of custom color. Values 0-255
		private var greenValue:uint;
		// blue value of custom color. Values 0-255
		private var blueValue:uint;

		// sound to play when peel is loaded
		private var loadSoundURL:String;

		// open with click. Values: 0/1
		private var open_onclick:uint;
		// speed of flag movement. Values: 1-9
		private var flagSpeed:uint;

		// test variables for media load
		private var small_loaded:Boolean = false;
		private var load_sound_loaded:Boolean = false;
		// loader for small image and mirror image
		private var small_ldr:Loader = new Loader();
		// loader for load sound
		private var loadSound:Sound = null;
		
		// delay seconds, curlypage start delayed
		private var delay:uint;
		private var timeSlot:uint;
		
		private var theflag:MovieClip;
		private var delayTimer:Timer;
		private var timeSlotTimer:Timer;

		/*
		 * FlagMovie Constructor
		 */
		public function FlagMovie () {
			loadParams();
			preload();
			ExternalInterface.addCallback("startTimeSlot", startTimeSlot);
		}

		/*
		 * Load Flag Movie Parameters
		 */
		private function loadParams () {
			
			cpid = this.loaderInfo.parameters.cpid || 0;

			inTransition = this.loaderInfo.parameters.inTransition || "Squeeze";
			transitionDuration = this.loaderInfo.parameters.transitionDuration || 4;
			
			flagStyle = this.loaderInfo.parameters.flagStyle || "style1";

			flagWidth = this.loaderInfo.parameters.flagWidth || FLAGDESIGNSIZE;
			flagHeight = this.loaderInfo.parameters.flagHeight || FLAGDESIGNSIZE;

			peelPosition = this.loaderInfo.parameters.peelPosition || "topright";

			smallURL = this.loaderInfo.parameters.smallURL || "small.jpg"; 
			mirror = Boolean(uint(this.loaderInfo.parameters.mirror)) || false;

			peelColor = this.loaderInfo.parameters.peelColor || "custom";
			peelColorStyle = this.loaderInfo.parameters.peelColorStyle || "gradient";
			redValue = this.loaderInfo.parameters.redValue || 0;
			greenValue = this.loaderInfo.parameters.greenValue || 0;
			blueValue = this.loaderInfo.parameters.blueValue || 0;

			loadSoundURL = this.loaderInfo.parameters.loadSoundURL || "";

			open_onclick = this.loaderInfo.parameters.open_onclick || 0;
			flagSpeed = this.loaderInfo.parameters.flagSpeed || 4;

			delay = this.loaderInfo.parameters.delay * 1000 || 0;
			timeSlot = this.loaderInfo.parameters.timeSlot * 1000 || 0;

		}
		
		/*
		 * start the Movie
		 */
		private function startMovie () {
			if (delay > 0) {
				delayTimer = new Timer(delay, 1);
				delayTimer.addEventListener(TimerEvent.TIMER, startFlag);
				delayTimer.start();
			}
			else {
				addFlag();
			}
		}
		
		private function startFlag(e:TimerEvent) : void {
			addFlag();
		}
		
		/*
		 * add Flag
		 */
		private function addFlag() {

			if (flagStyle == "style1") {
				theflag = new Style1Flag(cpid,
										 peelPosition,
										 mirror,
										 peelColor,
										 peelColorStyle,
										 redValue,
										 greenValue,
										 blueValue,
										 loadSound,
										 open_onclick,
										 flagSpeed,
										 small_ldr,
										 flagWidth,
										 flagHeight,
										 inTransition,
										 transitionDuration);
			} else if (flagStyle == "style2") {
				theflag = new Style2Flag(cpid,
										 peelPosition,
										 mirror,
										 peelColor,
										 peelColorStyle,
										 redValue,
										 greenValue,
										 blueValue,
										 loadSound,
										 open_onclick,
										 flagSpeed,
										 small_ldr,
										 flagWidth,
										 flagHeight,
										 inTransition,
										 transitionDuration);
			} else if (flagStyle == "style3") {
				theflag = new Style3Flag(cpid,
										 peelPosition,
										 mirror,
										 peelColor,
										 peelColorStyle,
										 redValue,
										 greenValue,
										 blueValue,
										 loadSound,
										 open_onclick,
										 flagSpeed,
										 small_ldr,
										 flagWidth,
										 flagHeight,
										 inTransition,
										 transitionDuration);
			}

			addChild(theflag);
			
			if (timeSlot > 0) {
				startTimeSlot();
			}

		}
		
		private function startTimeSlot() {
			timeSlotTimer = new Timer(timeSlot, 1);
			timeSlotTimer.addEventListener(TimerEvent.TIMER, finishCurlypage);
			timeSlotTimer.start();
		}

		private function finishCurlypage(e:TimerEvent) : void {
			ExternalInterface.call("curlypage_destroy", cpid, peelPosition);
		}

		/*
		 * Test if all media is loaded
 		 */
		private function allLoaded () : Boolean {

			if (!small_loaded) {
				return false;
			}
			
			if (!load_sound_loaded) {
				if (loadSoundURL != "") {
					return false;
				}
			}
	
			return true;

		}

		/*
		 * small image load event handler
		 */
		private function smallImageLoaded (e:Event) : void {
			small_loaded = true;
			if (allLoaded()) {
				startMovie();
			}
		}

		/*
 		 * load sound load event handler
 		 */
		private function loadSoundLoaded (e:Event) : void {
			load_sound_loaded = true;
			if (allLoaded()) {
				startMovie();
			}
		}

		/*
		 * Preload images & sounds
		 */
		private function preload() {

			small_ldr.contentLoaderInfo.addEventListener(Event.COMPLETE, smallImageLoaded);
			small_ldr.load(new URLRequest(smallURL));

			if (loadSoundURL != "") {
				loadSound = new Sound();
				loadSound.addEventListener(Event.COMPLETE, loadSoundLoaded);
				loadSound.load(new URLRequest(loadSoundURL));
			}

		}

	}
}

